pub(super) struct BlockWriteSender {
pub non_finalized: Option<UnboundedSender<NonFinalizedWriteMessage>>,
pub finalized: Option<UnboundedSender<(CheckpointVerifiedBlock, Sender<Result<Hash, CommitCheckpointVerifiedError>>)>>,
}Expand description
A worker with a task that reads, validates, and writes blocks to the
finalized_state or non_finalized_state and channels for sending
it blocks.
Fields
non_finalized: Option<UnboundedSender<NonFinalizedWriteMessage>>A channel to send blocks to the block_write_task,
so they can be written to the NonFinalizedState.
finalized: Option<UnboundedSender<(CheckpointVerifiedBlock, Sender<Result<Hash, CommitCheckpointVerifiedError>>)>>A channel to send blocks to the block_write_task,
so they can be written to the FinalizedState.
This sender is dropped after the state has finished sending all the checkpointed blocks, and the lowest semantically verified block arrives.
Implementations
Sourceimpl BlockWriteSender
impl BlockWriteSender
Sourcepub fn spawn(
finalized_state: FinalizedState,
non_finalized_state: NonFinalizedState,
chain_tip_sender: ChainTipSender,
non_finalized_state_sender: Sender<NonFinalizedState>,
should_use_finalized_block_write_sender: bool,
) -> (Self, UnboundedReceiver<Hash>, Option<Arc<JoinHandle<()>>>)
pub fn spawn( finalized_state: FinalizedState, non_finalized_state: NonFinalizedState, chain_tip_sender: ChainTipSender, non_finalized_state_sender: Sender<NonFinalizedState>, should_use_finalized_block_write_sender: bool, ) -> (Self, UnboundedReceiver<Hash>, Option<Arc<JoinHandle<()>>>)
Creates a new BlockWriteSender with the given receivers and states.